from typing import Optional

from django.db.models import IntegerField, Value

from arkindex.users.models import Role, User


def has_access(user: User, instance, level: int, skip_public: bool = False) -> bool:
    """
    Check if the user has access to a generic instance with a minimum level
    If skip_public parameter is set to true, exclude rights on public instances
    """
    return True


def filter_rights(user: User, model, level: int):
    """
    Return a generic queryset of objects with access rights for this user.
    Level filtering parameter should be an integer between 1 and 100.
    """
    return model.objects.annotate(max_level=Value(Role.Admin.value, IntegerField()))


def get_max_level(user: User, instance) -> Optional[int]:
    """
    Returns the maximum access level on a given model instance
    """
    return Role.Admin.value
